@@ -168,8 +168,8 @@ class OAuthService:
             
             # Update secrets
             if broker_link.broker_secret:
-                broker_link.broker_secret.encrypted_access_token = encrypted_access
-                broker_link.broker_secret.encrypted_refresh_token = encrypted_refresh
+                broker_link.broker_secret.enc_access_token = encrypted_access
+                broker_link.broker_secret.enc_refresh_token = encrypted_refresh
                 broker_link.broker_secret.access_expires_at = datetime.utcnow() + timedelta(
                     seconds=tokens.get("expires_in", 3600)
                 )
@@ -188,8 +188,8 @@ class OAuthService:
             broker_secret = BrokerSecret(
                 id=uuid4(),
                 broker_link_id=broker_link.id,
-                encrypted_access_token=encrypted_access,
-                encrypted_refresh_token=encrypted_refresh,
+                enc_access_token=encrypted_access,
+                enc_refresh_token=encrypted_refresh,
                 access_expires_at=datetime.utcnow() + timedelta(
                     seconds=tokens.get("expires_in", 3600)
                 ),
@@ -336,8 +336,8 @@ class OAuthService:
 
             # Update secrets
             if broker_link.broker_secret:
-                broker_link.broker_secret.encrypted_access_token = encrypted_access
-                broker_link.broker_secret.encrypted_refresh_token = encrypted_refresh
+                broker_link.broker_secret.enc_access_token = encrypted_access
+                broker_link.broker_secret.enc_refresh_token = encrypted_refresh
                 broker_link.broker_secret.access_expires_at = datetime.utcnow() + timedelta(
                     seconds=tokens.get("expires_in", 900)
                 )
@@ -356,8 +356,8 @@ class OAuthService:
             broker_secret = BrokerSecret(
                 id=uuid4(),
                 broker_link_id=broker_link.id,
-                encrypted_access_token=encrypted_access,
-                encrypted_refresh_token=encrypted_refresh,
+                enc_access_token=encrypted_access,
+                enc_refresh_token=encrypted_refresh,
                 access_expires_at=datetime.utcnow() + timedelta(
                     seconds=tokens.get("expires_in", 900)
                 ),
@@ -369,7 +369,8 @@ class OAuthService:
             self.session.add(broker_link)
             self.session.add(broker_secret)
 
-        await self.session.commit()
+        # Note: Commit is handled by the session context manager
+        # Don't manually commit here to avoid greenlet context issues
 
         logger.info(
             "Personal grant setup completed",
@@ -398,7 +399,7 @@ class OAuthService:
         # Decrypt refresh token
         encryption = await get_encryption_service()
         refresh_token = await encryption.decrypt_token(
-            broker_link.broker_secret.encrypted_refresh_token,
+            broker_link.broker_secret.enc_refresh_token,
             token_type="refresh",
         )
         
@@ -426,23 +427,24 @@ class OAuthService:
             tokens["access_token"],
             token_type="access",
         )
-        
-        broker_link.broker_secret.encrypted_access_token = encrypted_access
+
+        broker_link.broker_secret.enc_access_token = encrypted_access
         broker_link.broker_secret.access_expires_at = datetime.utcnow() + timedelta(
             seconds=tokens.get("expires_in", 3600)
         )
-        
+
         # Update refresh token if provided
         if "refresh_token" in tokens:
             encrypted_refresh = await encryption.encrypt_token(
                 tokens["refresh_token"],
                 token_type="refresh",
             )
-            broker_link.broker_secret.encrypted_refresh_token = encrypted_refresh
-        
+            broker_link.broker_secret.enc_refresh_token = encrypted_refresh
+
         broker_link.broker_secret.updated_at = datetime.utcnow()
-        await self.session.commit()
-        
+        # Note: Commit is handled by the session context manager
+        # Don't manually commit here to avoid greenlet context issues
+
         logger.info(
             "Tokens refreshed",
             extra={"broker_link_id": str(broker_link.id)}
@@ -465,7 +467,7 @@ class OAuthService:
         # Decrypt access token
         encryption = await get_encryption_service()
         access_token = await encryption.decrypt_token(
-            broker_link.broker_secret.encrypted_access_token,
+            broker_link.broker_secret.enc_access_token,
             token_type="access",
         )
         
@@ -495,9 +497,10 @@ class OAuthService:
         # Clear tokens
         await self.session.delete(broker_link.broker_secret)
         broker_link.broker_secret = None
-        
-        await self.session.commit()
-        
+
+        # Note: Commit is handled by the session context manager
+        # Don't manually commit here to avoid greenlet context issues
+
         logger.info(
             "Tokens revoked",
             extra={"broker_link_id": str(broker_link.id)}
