@@ -448,6 +448,9 @@ def setup(
                 use_production=use_production
             )
 
+            # Reload environment variables from the newly created .env file
+            load_dotenv(env_path, override=True)
+
             # Initialize database with user setup
             console.print("\n[blue]Setting up database with encrypted tokens...[/blue]")
             user_id = asyncio.run(setup_database_mode(
